##
##  docker-distribution.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2015 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
%define       V_docker_distribution_base  2.0
%define       V_docker_distribution_snap  20150624

#   package information
Name:         docker-distribution
Summary:      Docker Registry & Content Distribution
URL:          https://github.com/docker/distribution
Vendor:       Docker Project
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        Database
License:      Apache
Version:      %{V_docker_distribution_base}
Release:      20150624

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/docker-distribution/docker-distribution-%{V_docker_distribution_snap}.tar.xz
Source1:      rc.docker-distribution
Source2:      docker-registry.yml
Source3:      docker-registry.pwd
Source4:      docker-passwd.sh

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20140101, go, apg
PreReq:       OpenPKG, openpkg >= 20140101, x509, perl

%description
    This is the Docker toolset to pack, ship, store, and deliver
    content. The main product is the Docker Registry implementation for
    storing and distributing Docker images.

%track
    prog docker-distribution = {
        version   = %{V_docker_distribution_snap}
        url       = http://download.openpkg.org/components/versioned/docker-distribution/
        regex     = docker-distribution-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n docker-distribution

%build
    #   build program
    export GOPATH=`pwd`
    cd $GOPATH/src/github.com/docker/distribution
    mkdir bin
    go build -x ./...
    go build -x -o bin/dist cmd/dist/*.go
    go build -x -o bin/registry cmd/registry/main.go
    go build -x -o bin/registry-api-descriptor-template cmd/registry-api-descriptor-template/main.go
    %{l_make} %{l_mflags} docs/spec/api.md

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/docker-distribution \
        $RPM_BUILD_ROOT%{l_prefix}/var/docker-distribution/run \
        $RPM_BUILD_ROOT%{l_prefix}/var/docker-distribution/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/docker-distribution/data

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/docker/distribution/bin/dist \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/docker-dist
    %{l_shtool} install -c -s -m 755 \
        src/github.com/docker/distribution/bin/registry \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/docker-registry

    #   install password utility
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE docker-passwd.sh} \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/docker-passwd

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.docker-distribution} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        -e "s;@secret@;`apg -n1 -a1 -m64 -x64 -M NCL`;" \
        %{SOURCE docker-registry.yml} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/docker-distribution/
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE docker-registry.pwd} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/docker-distribution/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/docker-distribution/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/docker-distribution/*'

%files -f files

%clean

%post
    #   after upgrade, restart service
    if [ $1 -eq 1 ]; then
        ( echo "You can access your Docker Registry under the URL:"
          echo "    http://127.0.0.1:5001/"
          echo "A default user 'docker' with password 'docker' was pre-configured."
          echo "Set a new password with:"
          echo "    \$ $RPM_INSTALL_PREFIX/sbin/docker-passwd docker <password>"
        ) | %{l_rpmtool} msg -b -t notice
    elif [ $1 -eq 2 ]; then
        eval `%{l_rc} docker-distribution status 2>/dev/null`
        [ ".$docker_distribution_active" = .yes ] && %{l_rc} docker-distribution restart
    fi
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} docker-distribution stop 2>/dev/null
    rm -rf $RPM_INSTALL_PREFIX/var/docker-distribution/log/*  >/dev/null 2>&1 || true
    rm -rf $RPM_INSTALL_PREFIX/var/docker-distribution/run/*  >/dev/null 2>&1 || true
    rm -rf $RPM_INSTALL_PREFIX/var/docker-distribution/data/* >/dev/null 2>&1 || true
    exit 0

